@@ -27,6 +27,15 @@ class Collpay:
         response = self.__make_request("exchange-rate", "post", data)
         return response
 
+    def create_transaction(self, transaction_data):
+        response = self.__make_request("exchange-rate", "post", transaction_data)
+        return response
+
+    def get_transaction(self, transaction_id):
+        url = f"transactions/{transaction_id}"
+        response = self.__make_request(url, "get")
+        return response
+
     def __make_request(self, url, method, data=None):
         try:
             headers = {
